@@ -31,7 +31,7 @@ int CTHour::findPeriod() const {
 QString CTHour::exportUnit() const {
 	int period = findPeriod();
 	if (period!=0 && period!=1)
-		return QString(QLatin1String( "*/%1" )).arg(QString::number(period));
+		return QStringLiteral( "*/%1" ).arg(QString::number(period));
 
 	return CTUnit::exportUnit();
 }
